@@ -11,7 +11,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tkCanvPs.c 1.57 97/10/28 18:08:39
+ * RCS: @(#) $Id: tkCanvPs.c,v 1.4 1998/09/22 18:57:16 stanton Exp $
  */
 
 #include "tkInt.h"
@@ -127,7 +127,7 @@ static CONST char * CONST  prolog[]= {
 \n\
 % This is a standard prolog for Postscript generated by Tk's canvas\n\
 % widget.\n\
-% SCCS: @(#) prolog.ps 1.7 96/07/08 17:52:14\n\
+% RCS: @(#) $Id: tkCanvPs.c,v 1.4 1998/09/22 18:57:16 stanton Exp $\n\
 \n\
 % The definitions below just define all of the variables used in\n\
 % any of the procedures here.  This is needed for obscure reasons\n\
