@@ -11,7 +11,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tkImage.c 1.15 97/10/09 09:57:50
+ * RCS: @(#) $Id: tkImage.c,v 1.2 1998/09/14 18:23:12 stanton Exp $
  */
 
 #include "tkInt.h"
@@ -69,6 +69,9 @@ static Blt_ListItem *Blt_NewItem _ANSI_ARGS_((char *key));
 static void Blt_LinkAfter _ANSI_ARGS_((Blt_List *listPtr,
 	Blt_ListItem *itemPtr, Blt_ListItem *afterPtr));
 static void Blt_FreeItem _ANSI_ARGS_((Blt_ListItem *itemPtr));
+static void TileChangedProc _ANSI_ARGS_((ClientData clientData,
+	int x, int y, int width, int height, int imageWidth,
+	int imageHeight));
 
 #define Blt_FirstListItem(listPtr)	((listPtr)->headPtr)
 #define Blt_NextItem(itemPtr) 		((itemPtr)->nextPtr)
