@@ -11,7 +11,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tkMessage.c 1.75 97/07/31 09:11:14
+ * RCS: @(#) $Id: tkMessage.c,v 1.2 1998/09/14 18:23:15 stanton Exp $
  */
 
 #include "tkPort.h"
@@ -194,6 +194,8 @@ static int		ConfigureMessage _ANSI_ARGS_((Tcl_Interp *interp,
 			    int flags));
 static void		DestroyMessage _ANSI_ARGS_((char *memPtr));
 static void		DisplayMessage _ANSI_ARGS_((ClientData clientData));
+static void		TileChangedProc _ANSI_ARGS_((ClientData clientData,
+			    Tk_Tile tile, Tk_Item *itemPtr));
 
 /*
  * The structure below defines message class behavior by means of procedures
@@ -281,7 +283,7 @@ Tk_MessageCmd(clientData, interp, argc, argv)
     msgPtr->tile = NULL;
     msgPtr->tileGC = NULL;
 
-    Tk_SetClass(msgPtr->tkwin, "Message");
+    TkClassOption(msgPtr->tkwin, "Message",&argc,&argv);
     TkSetClassProcs(msgPtr->tkwin, &messageClass, (ClientData) msgPtr);
     Tk_CreateEventHandler(msgPtr->tkwin,
 	    ExposureMask|StructureNotifyMask|FocusChangeMask,
