@@ -10,7 +10,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tkRectOval.c 1.40 96/05/03 10:52:21
+ * RCS: @(#) $Id: tkRectOval.c,v 1.2 1998/09/14 18:23:16 stanton Exp $
  */
 
 #include <stdio.h>
@@ -732,7 +732,7 @@ ComputeRectOvalBbox(canvas, rectOvalPtr)
     if (rectOvalPtr->outline.gc == None) {
 	bloat = 0;
     } else {
-	bloat = (width+1)/2;
+	bloat = (int) (width+1)/2;
     }
 
     /*
@@ -752,13 +752,13 @@ ComputeRectOvalBbox(canvas, rectOvalPtr)
 	dtmp = rectOvalPtr->bbox[0] + 1;
     }
     tmp = (int) ((dtmp >= 0) ? dtmp + .5 : dtmp - .5);
-    rectOvalPtr->header.x2 = tmp + bloat;
+    rectOvalPtr->header.x2 = tmp + bloat + 1;
     dtmp = rectOvalPtr->bbox[3];
     if (dtmp < (rectOvalPtr->bbox[1] + 1)) {
 	dtmp = rectOvalPtr->bbox[1] + 1;
     }
     tmp = (int) ((dtmp >= 0) ? dtmp + .5 : dtmp - .5);
-    rectOvalPtr->header.y2 = tmp + bloat;
+    rectOvalPtr->header.y2 = tmp + bloat + 1;
 }
 
 /*
