@@ -3,7 +3,7 @@
 # This file defines the default bindings for Tk entry widgets and provides
 # procedures that help in implementing those bindings.
 #
-# SCCS: @(#) entry.tcl 1.49 97/09/17 19:08:48
+# RCS: @(#) $Id: entry.tcl,v 1.5 1998/09/14 18:23:23 stanton Exp $
 #
 # Copyright (c) 1992-1994 The Regents of the University of California.
 # Copyright (c) 1994-1997 Sun Microsystems, Inc.
@@ -31,7 +31,6 @@
 #-------------------------------------------------------------------------
 # The code below creates the default class bindings for entries.
 #-------------------------------------------------------------------------
-
 bind Entry <<Cut>> {
     if {![catch {set data [string range [%W get] [%W index sel.first]\
 	    [expr {[%W index sel.last] - 1}]]}]} {
@@ -50,7 +49,7 @@ bind Entry <<Copy>> {
 bind Entry <<Paste>> {
     global tcl_platform
     catch {
-	if {"$tcl_platform(platform)" != "unix"} {
+	if {[string compare $tcl_platform(platform) unix]} {
 	    catch {
 		%W delete sel.first sel.last
 	    }
@@ -62,6 +61,11 @@ bind Entry <<Paste>> {
 bind Entry <<Clear>> {
     %W delete sel.first sel.last
 }
+bind Entry <<PasteSelection>> {
+    if {!$tkPriv(mouseMoved) || $tk_strictMotif} {
+	tkEntryPaste %W %x
+    }
+}
 
 # Standard Motif bindings:
 
@@ -108,11 +112,6 @@ bind Entry <ButtonRelease-1> {
 bind Entry <Control-1> {
     %W icursor @%x
 }
-bind Entry <ButtonRelease-2> {
-    if {!$tkPriv(mouseMoved) || $tk_strictMotif} {
-	tkEntryPaste %W %x
-    }
-}
 
 bind Entry <Left> {
     tkEntrySetCursor %W [expr {[%W index insert] - 1}]
@@ -202,12 +201,16 @@ bind Entry <Escape> {# nothing}
 bind Entry <Return> {# nothing}
 bind Entry <KP_Enter> {# nothing}
 bind Entry <Tab> {# nothing}
-if {$tcl_platform(platform) == "macintosh"} {
+if {![string compare $tcl_platform(platform) macintosh]} {
 	bind Entry <Command-KeyPress> {# nothing}
 }
 
-bind Entry <Insert> {
-    catch {tkEntryInsert %W [selection get -displayof %W]}
+# On Windows, paste is done using Shift-Insert.  Shift-Insert already
+# generates the <<Paste>> event, so we don't need to do anything here.
+if {[string compare $tcl_platform(platform) windows]} {
+    bind Entry <Insert> {
+	catch {tkEntryInsert %W [selection get -displayof %W]}
+    }
 }
 
 # Additional emacs-like bindings:
@@ -332,7 +335,7 @@ proc tkEntryButton1 {w x} {
     set tkPriv(pressX) $x
     $w icursor [tkEntryClosestGap $w $x]
     $w selection from insert
-    if {[lindex [$w configure -state] 4] == "normal"} {focus $w}
+    if {![string compare [$w cget -state] normal]} {focus $w}
 }
 
 # tkEntryMouseSelect --
@@ -402,7 +405,7 @@ proc tkEntryPaste {w x} {
 
     $w icursor [tkEntryClosestGap $w $x]
     catch {$w insert insert [selection get -displayof $w]}
-    if {[lindex [$w configure -state] 4] == "normal"} {focus $w}
+    if {![string compare [$w cget -state] normal]} {focus $w}
 }
 
 # tkEntryAutoScan --
@@ -459,7 +462,7 @@ proc tkEntryKeySelect {w new} {
 # s -		The string to insert (usually just a single character)
 
 proc tkEntryInsert {w s} {
-    if {$s == ""} {
+    if {![string compare $s {}]} {
 	return
     }
     catch {
@@ -659,7 +662,7 @@ proc tkEntryTranspose w {
 # w -		The entry window in which the cursor is to move.
 # start -	Position at which to start search.
 
-if {$tcl_platform(platform) == "windows"}  {
+if {![string compare $tcl_platform(platform) windows]}  {
     proc tkEntryNextWord {w start} {
 	set pos [tcl_endOfWord [$w get] [$w index $start]]
 	if {$pos >= 0} {
