@@ -10,7 +10,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tkMacDraw.c 1.55 97/11/20 18:28:56
+ * RCS: @(#) $Id: tkMacDraw.c,v 1.2 1998/09/14 18:23:35 stanton Exp $
  */
 
 #include "tkInt.h"
@@ -989,8 +989,9 @@ TkMacSetUpGraphicsPort(
 	 *
 	 *	Jan Nijtmans
 	 *	NICI (Nijmegen Institute of Cognition and Information)
-	 *	email: nijtmans@nici.kun.nl
-	 *	url:   http://www.cogsci.kun.nl/~nijtmans/
+	 *	email: Jan.Nijtmans@cmg.nl (work)
+	 *	       Jan.Nijtmans@wxs.nl (private)
+	 *	url:   http://home.wxs.nl/~nijtmans/
 	 */
     }
 }
