@@ -10,7 +10,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tkWinDraw.c 1.30 97/03/21 11:20:05
+ * RCS: @(#) $Id: tkWinDraw.c,v 1.2 1998/09/14 18:24:00 stanton Exp $
  */
 
 #include "tkWinInt.h"
@@ -110,6 +110,7 @@ typedef BOOL (CALLBACK *WinDrawFunc) _ANSI_ARGS_((HDC dc,
  * Forward declarations for procedures defined in this file:
  */
 
+static HPEN		SetUpGraphicsPort _ANSI_ARGS_((GC gc));
 static POINT *		ConvertPoints _ANSI_ARGS_((XPoint *points, int npoints,
 			    int mode, RECT *bbox));
 static void		DrawOrFillArc _ANSI_ARGS_((Display *display,
@@ -119,7 +120,6 @@ static void		DrawOrFillArc _ANSI_ARGS_((Display *display,
 static void		RenderObject _ANSI_ARGS_((HDC dc, GC gc,
 			    XPoint* points, int npoints, int mode, HPEN pen,
 			    WinDrawFunc func));
-static HPEN		SetUpGraphicsPort _ANSI_ARGS_((GC gc));
 
 /*
  *----------------------------------------------------------------------
@@ -1170,6 +1170,16 @@ DrawOrFillArc(display, d, gc, x, y, width, height, start, extent, fill)
  *----------------------------------------------------------------------
  */
 
+#ifndef TkWinCreatePen
+#define TkWinCreatePen(gc, style, width, foreground) \
+	CreatePen(style, width, foreground)
+#endif
+
+#ifndef TkWinExtCreatePen
+#define TkWinExtCreatePen(gc, style, width, brush, count, lp) \
+	ExtCreatePen(style, width, brush, count, lp)
+#endif
+
 static HPEN
 SetUpGraphicsPort(gc)
     GC gc;
@@ -1184,7 +1194,7 @@ SetUpGraphicsPort(gc)
 	 * Below is a simple translation of serveral dash patterns
 	 * to valid windows pen types. Far from complete,
 	 * but I don't know how to do it better.
-	 * Any ideas: <mailto:nijtmans@nici.kun.nl>
+	 * Any ideas: <mailto:Jan.Nijtmans@wxs.nl>
 	 */
 
 	if (p[1] && p[2]) {
@@ -1207,7 +1217,7 @@ SetUpGraphicsPort(gc)
 	if (gc->line_width > 1) {
 	    style = PS_SOLID;
 	}
-	return CreatePen(style, gc->line_width, gc->foreground);
+	return TkWinCreatePen(gc, style, gc->line_width, gc->foreground);
     } else {
 	LOGBRUSH lb;
 
@@ -1239,7 +1249,7 @@ SetUpGraphicsPort(gc)
 		style |= PS_JOIN_BEVEL; 
 		break;
 	}
-	return ExtCreatePen(style, gc->line_width, &lb, 0, NULL);
+	return TkWinExtCreatePen(gc, style, gc->line_width, &lb, 0, NULL);
     }
 }
 
